# Changelog

## [0.1.1](https://github.com/gotalab/skillport/compare/v0.1.0...v0.1.1) (2025-12-02)


### Features

* **cli:** add global skills/db overrides ([c6bd235](https://github.com/gotalab/skillport/commit/c6bd2352609202fa627b89f845a9ca0ca96fa087))
* **cli:** add global skills/db overrides ([a8d3c44](https://github.com/gotalab/skillport/commit/a8d3c44ccb5aa692156ec29b71060b97ae353883))
* derive db/meta per skills dir and improve add UX ([111889a](https://github.com/gotalab/skillport/commit/111889a386439225d8b9831ca06ed0e96283881b))
* initial release ([82cdaea](https://github.com/gotalab/skillport/commit/82cdaea69cfc22aa93307f94b0ef3be83131782b))


### Bug Fixes

* clean prefetched github temp dir after rename ([780cd5d](https://github.com/gotalab/skillport/commit/780cd5d5409bf1e09f0adfdb21152e7f516ff597))
* reuse fetched source and embedding defaults ([d250ea3](https://github.com/gotalab/skillport/commit/d250ea377676e8df4ae789b93b3db58d8963d658))


### Documentation

* align config sample to AGENTS+GEMINI ([eb900b6](https://github.com/gotalab/skillport/commit/eb900b663c7d69d6210cde0664597d092d236bad))
* mention Antigravity in other clients list ([99778c7](https://github.com/gotalab/skillport/commit/99778c78c68900575e7c93d67730d1e4feede01c))


### Miscellaneous Chores

* set release package name ([6e63e66](https://github.com/gotalab/skillport/commit/6e63e666427930dc62baac842ea61070a29ded6a))
